@@ -1,4 +1,4 @@
-/* $Id: files.c 4460 2009-12-09 16:51:43Z astyanax $ */
+/* $Id: files.c 4474 2010-01-14 06:32:37Z astyanax $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -309,7 +309,7 @@ int is_file_writable(const char *filename)
     if (ISSET(VIEW_MODE))
 	return TRUE;
 
-    assert(filename != NULL && f != NULL);
+    assert(filename != NULL);
 
     /* Get the specified file's full path. */
     full_filename = get_full_path(filename);
@@ -1500,6 +1500,13 @@ bool write_file(const char *name, FILE *f_open, bool tmp, append_type
     realexists = (stat(realname, &st) != -1);
 
 #ifndef NANO_TINY
+    /* if we have not stat()d this file before (say, the user just
+     * specified it interactively), use the info we just got from
+     * stat()ing or else we will chase null pointers when we do
+     * modtime checks, preserve file times, etc. during backup */
+    if (openfile->current_stat == NULL && realexists)
+	openfile->current_stat = &st;
+
     /* We backup only if the backup toggle is set, the file isn't
      * temporary, and the file already exists.  Furthermore, if we
      * aren't appending, prepending, or writing a selection, we backup
@@ -2118,6 +2125,7 @@ bool do_writeout(bool exiting)
 		    }
 		}
 #ifndef NANO_TINY
+
 		if (name_exists && openfile->current_stat && openfile->current_stat->st_mtime < st.st_mtime) {
 		    i = do_yesno_prompt(FALSE,
 			_("File was modified since you opened it, continue saving ? "));
