@@ -1,4 +1,4 @@
-/* $Id: nano.c 4462 2009-12-12 22:21:20Z astyanax $ */ 
+/* $Id: nano.c 4477 2010-01-18 03:43:24Z astyanax $ */ 
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -518,6 +518,7 @@ openfilestruct *make_new_opennode(void)
     newnode->edittop = NULL;
     newnode->current = NULL;
 #ifndef NANO_TINY
+    newnode->current_stat = NULL;
     newnode->last_action = OTHER;
 #endif
 
@@ -1625,7 +1626,7 @@ int do_input(bool *meta_key, bool *func_key, bool *s_or_t, bool
 #endif
 				iso_me_harder_funcmap(s->scfunc);
 #ifdef ENABLE_COLOR
-				if (!f->viewok && openfile->syntax != NULL
+				if (f && !f->viewok && openfile->syntax != NULL
 					&& openfile->syntax->nmultis > 0) {
 				    reset_multis(openfile->current, FALSE);
 				}
